@@ -3,8 +3,8 @@
 ;; Copyright (c) 2025 neeasade
 ;; SPDX-License-Identifier: MIT
 ;;
-;; Package-Version: 20250221.2339
-;; Package-Revision: e3d082136e06
+;; Package-Version: 20260114.1214
+;; Package-Revision: 66fb78baf835
 ;; Author: neeasade
 ;; Keywords: convenience color theming rgb hsv hsl lab oklab background
 ;; URL: https://github.com/neeasade/ct.el
@@ -614,12 +614,12 @@ results."
 (defun ct-greaten (color &optional percent)
   "Make a light COLOR lighter, a dark COLOR darker (by PERCENT)."
   (ct-edit-lab-l-inc color
-    (* percent (if (ct-light-p color) 1 -1))))
+    (* (or percent 0.1) (if (ct-light-p color) 1 -1))))
 
 (defun ct-lessen (color &optional percent)
   "Make a light COLOR darker, or a dark COLOR lighter (by PERCENT)."
   (ct-edit-lab-l-inc color
-    (* percent (if (ct-light-p color) -1 1))))
+    (* (or percent 0.1) (if (ct-light-p color) -1 1))))
 
 (defmacro ct-change (color distance edit-fn)
   "Change COLOR using EDIT-FN until DISTANCE is reached."
